@@ -89,7 +89,7 @@ def execute_query_from_cli(workspace_process_context, query, variables=None, out
         with open(output, "w", encoding="utf8") as f:
             f.write(str_res + "\n")
     else:
-        print(str_res)  # pylint: disable=print-call
+        print(str_res)  # noqa: T201
 
     return str_res
 
@@ -105,9 +105,7 @@ def execute_query_against_remote(host, query, variables):
     sanity_check = requests.get(urljoin(host, "/dagit_info"))
     sanity_check.raise_for_status()
     if "dagit" not in sanity_check.text:
-        raise click.UsageError(
-            "Host {host} failed sanity check. It is not a dagit server.".format(host=host)
-        )
+        raise click.UsageError(f"Host {host} failed sanity check. It is not a dagit server.")
     response = requests.post(
         urljoin(host, "/graphql"),
         # send query and vars as post body to avoid uri length limits
@@ -196,7 +194,7 @@ def ui(text, file, predefined, variables, remote, output, ephemeral_instance, **
 
     if remote:
         res = execute_query_against_remote(remote, query, variables)
-        print(res)  # pylint: disable=print-call
+        print(res)  # noqa: T201
     else:
         instance = DagsterInstance.ephemeral() if ephemeral_instance else DagsterInstance.get()
         with get_workspace_process_context_from_kwargs(
