@@ -16,9 +16,7 @@ fragment errorFragment on PythonError {
 }
 """
 
-STEP_EVENT_FRAGMENTS = (
-    ERROR_FRAGMENT
-    + """
+METADATA_ENTRY_FRAGMENT = """
 fragment metadataEntryFragment on MetadataEntry {
   __typename
   label
@@ -86,7 +84,12 @@ fragment metadataEntryFragment on MetadataEntry {
     }
   }
 }
+"""
 
+STEP_EVENT_FRAGMENTS = (
+    ERROR_FRAGMENT
+    + METADATA_ENTRY_FRAGMENT
+    + """
 fragment stepEventFragment on StepEvent {
   stepKey
   solidHandleID
