@@ -58,7 +58,7 @@ def do_launch(
 
 
 def _launch_pipeline_execution(
-    graphene_info, execution_params: ExecutionParams, is_reexecuted: bool = False
+    graphene_info: "ResolveInfo", execution_params: ExecutionParams, is_reexecuted: bool = False
 ) -> "GrapheneLaunchRunSuccess":
     from ...schema.pipelines.pipeline import GrapheneRun
     from ...schema.runs import GrapheneLaunchRunSuccess
@@ -76,9 +76,7 @@ def _launch_pipeline_execution(
 def launch_reexecution_from_parent_run(
     graphene_info: "ResolveInfo", parent_run_id: str, strategy: str
 ) -> "GrapheneLaunchRunSuccess":
-    """
-    Launch a re-execution by referencing the parent run id.
-    """
+    """Launch a re-execution by referencing the parent run id."""
     from ...schema.pipelines.pipeline import GrapheneRun
     from ...schema.runs import GrapheneLaunchRunSuccess
 
@@ -90,7 +88,7 @@ def launch_reexecution_from_parent_run(
     )
     origin = check.not_none(parent_run.external_pipeline_origin)
     selector = PipelineSelector(
-        location_name=origin.external_repository_origin.repository_location_origin.location_name,
+        location_name=origin.external_repository_origin.code_location_origin.location_name,
         repository_name=origin.external_repository_origin.repository_name,
         pipeline_name=parent_run.pipeline_name,
         solid_selection=None,
@@ -102,12 +100,12 @@ def launch_reexecution_from_parent_run(
         selector.location_name,
     )
 
-    repo_location = graphene_info.context.get_repository_location(selector.location_name)
+    repo_location = graphene_info.context.get_code_location(selector.location_name)
     external_pipeline = get_external_pipeline_or_raise(graphene_info, selector)
 
     run = instance.create_reexecuted_run(
         parent_run=cast(DagsterRun, parent_run),
-        repo_location=repo_location,
+        code_location=repo_location,
         external_pipeline=external_pipeline,
         strategy=ReexecutionStrategy(strategy),
         use_parent_run_tags=True,  # inherit whatever tags were set on the parent run at launch time
