@@ -1,11 +1,16 @@
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from dagster._core.storage.captured_log_manager import CapturedLogManager
 
 from dagster_graphql.schema.util import ResolveInfo
 
+if TYPE_CHECKING:
+    from ..schema.logs.compute_logs import GrapheneCapturedLogsMetadata
 
-def get_captured_log_metadata(graphene_info: ResolveInfo, log_key: Sequence[str]):
+
+def get_captured_log_metadata(
+    graphene_info: ResolveInfo, log_key: Sequence[str]
+) -> "GrapheneCapturedLogsMetadata":
     from ..schema.logs.compute_logs import GrapheneCapturedLogsMetadata
 
     if not isinstance(graphene_info.context.instance.compute_log_manager, CapturedLogManager):
