@@ -1,3 +1,5 @@
+from typing import TYPE_CHECKING, Optional, Sequence
+
 import dagster._check as check
 from dagster._core.definitions.run_request import InstigatorType
 from dagster._core.definitions.selector import (
@@ -5,6 +7,7 @@ from dagster._core.definitions.selector import (
     RepositorySelector,
     ScheduleSelector,
 )
+from dagster._core.scheduler.instigation import InstigatorState
 from dagster._core.workspace.permissions import Permissions
 from dagster._seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
 
@@ -18,14 +21,25 @@ from .utils import (
     capture_error,
 )
 
+if TYPE_CHECKING:
+    from ..schema.instigation import GrapheneDryRunInstigationTick
+    from ..schema.schedules import (
+        GrapheneSchedule,
+        GrapheneScheduler,
+        GrapheneSchedules,
+        GrapheneScheduleStateResult,
+    )
+
 
 @capture_error
-def start_schedule(graphene_info: ResolveInfo, schedule_selector):
+def start_schedule(
+    graphene_info: ResolveInfo, schedule_selector: ScheduleSelector
+) -> "GrapheneScheduleStateResult":
     from ..schema.instigation import GrapheneInstigationState
     from ..schema.schedules import GrapheneScheduleStateResult
 
     check.inst_param(schedule_selector, "schedule_selector", ScheduleSelector)
-    location = graphene_info.context.get_repository_location(schedule_selector.location_name)
+    location = graphene_info.context.get_code_location(schedule_selector.location_name)
     repository = location.get_repository(schedule_selector.repository_name)
     instance = graphene_info.context.instance
     schedule_state = instance.start_schedule(
@@ -35,7 +49,9 @@ def start_schedule(graphene_info: ResolveInfo, schedule_selector):
 
 
 @capture_error
-def stop_schedule(graphene_info: ResolveInfo, schedule_origin_id, schedule_selector_id):
+def stop_schedule(
+    graphene_info: ResolveInfo, schedule_origin_id: str, schedule_selector_id: str
+) -> "GrapheneScheduleStateResult":
     from ..schema.instigation import GrapheneInstigationState
     from ..schema.schedules import GrapheneScheduleStateResult
 
@@ -43,7 +59,7 @@ def stop_schedule(graphene_info: ResolveInfo, schedule_origin_id, schedule_selec
 
     external_schedules = {
         job.get_external_origin_id(): job
-        for repository_location in graphene_info.context.repository_locations
+        for repository_location in graphene_info.context.code_locations
         for repository in repository_location.get_repositories().values()
         for job in repository.get_external_schedules()
     }
@@ -69,7 +85,7 @@ def stop_schedule(graphene_info: ResolveInfo, schedule_origin_id, schedule_selec
 
 
 @capture_error
-def get_scheduler_or_error(graphene_info: ResolveInfo):
+def get_scheduler_or_error(graphene_info: ResolveInfo) -> "GrapheneScheduler":
     from ..schema.errors import GrapheneSchedulerNotDefinedError
     from ..schema.schedules import GrapheneScheduler
 
@@ -82,12 +98,14 @@ def get_scheduler_or_error(graphene_info: ResolveInfo):
 
 
 @capture_error
-def get_schedules_or_error(graphene_info: ResolveInfo, repository_selector):
+def get_schedules_or_error(
+    graphene_info: ResolveInfo, repository_selector: RepositorySelector
+) -> "GrapheneSchedules":
     from ..schema.schedules import GrapheneSchedule, GrapheneSchedules
 
     check.inst_param(repository_selector, "repository_selector", RepositorySelector)
 
-    location = graphene_info.context.get_repository_location(repository_selector.location_name)
+    location = graphene_info.context.get_code_location(repository_selector.location_name)
     repository = location.get_repository(repository_selector.repository_name)
     batch_loader = RepositoryScopedBatchLoader(graphene_info.context.instance, repository)
     external_schedules = repository.get_external_schedules()
@@ -110,12 +128,14 @@ def get_schedules_or_error(graphene_info: ResolveInfo, repository_selector):
     return GrapheneSchedules(results=results)
 
 
-def get_schedules_for_pipeline(graphene_info: ResolveInfo, pipeline_selector):
+def get_schedules_for_pipeline(
+    graphene_info: ResolveInfo, pipeline_selector: PipelineSelector
+) -> Sequence["GrapheneSchedule"]:
     from ..schema.schedules import GrapheneSchedule
 
     check.inst_param(pipeline_selector, "pipeline_selector", PipelineSelector)
 
-    location = graphene_info.context.get_repository_location(pipeline_selector.location_name)
+    location = graphene_info.context.get_code_location(pipeline_selector.location_name)
     repository = location.get_repository(pipeline_selector.repository_name)
     external_schedules = repository.get_external_schedules()
 
@@ -134,12 +154,14 @@ def get_schedules_for_pipeline(graphene_info: ResolveInfo, pipeline_selector):
 
 
 @capture_error
-def get_schedule_or_error(graphene_info: ResolveInfo, schedule_selector):
+def get_schedule_or_error(
+    graphene_info: ResolveInfo, schedule_selector: ScheduleSelector
+) -> "GrapheneSchedule":
     from ..schema.errors import GrapheneScheduleNotFoundError
     from ..schema.schedules import GrapheneSchedule
 
     check.inst_param(schedule_selector, "schedule_selector", ScheduleSelector)
-    location = graphene_info.context.get_repository_location(schedule_selector.location_name)
+    location = graphene_info.context.get_code_location(schedule_selector.location_name)
     repository = location.get_repository(schedule_selector.repository_name)
 
     if not repository.has_external_schedule(schedule_selector.schedule_name):
@@ -155,24 +177,26 @@ def get_schedule_or_error(graphene_info: ResolveInfo, schedule_selector):
     return GrapheneSchedule(external_schedule, schedule_state)
 
 
-def get_schedule_next_tick(graphene_info: ResolveInfo, schedule_state):
+def get_schedule_next_tick(
+    graphene_info: ResolveInfo, schedule_state: InstigatorState
+) -> Optional["GrapheneDryRunInstigationTick"]:
     from ..schema.instigation import GrapheneDryRunInstigationTick
 
     if not schedule_state.is_running:
         return None
 
     repository_origin = schedule_state.origin.external_repository_origin
-    if not graphene_info.context.has_repository_location(
-        repository_origin.repository_location_origin.location_name
+    if not graphene_info.context.has_code_location(
+        repository_origin.code_location_origin.location_name
     ):
         return None
-    repository_location = graphene_info.context.get_repository_location(
-        repository_origin.repository_location_origin.location_name
+    code_location = graphene_info.context.get_code_location(
+        repository_origin.code_location_origin.location_name
     )
-    if not repository_location.has_repository(repository_origin.repository_name):
+    if not code_location.has_repository(repository_origin.repository_name):
         return None
 
-    repository = repository_location.get_repository(repository_origin.repository_name)
+    repository = code_location.get_repository(repository_origin.repository_name)
 
     if not repository.has_external_schedule(schedule_state.name):
         return None
