@@ -16,12 +16,10 @@ from dagster._core.host_representation.external_data import (
     ExternalAssetDependency,
     ExternalAssetNode,
 )
-from dagster._core.instance import DynamicPartitionsStore
 from dagster._core.scheduler.instigation import InstigatorState, InstigatorType
 from dagster._core.storage.pipeline_run import JobBucket, RunRecord, RunsFilter, TagBucket
 from dagster._core.storage.tags import REPOSITORY_LABEL_TAG, SCHEDULE_NAME_TAG, SENSOR_NAME_TAG
 from dagster._core.workspace.context import WorkspaceRequestContext
-from dagster._utils.cached_method import cached_method
 
 
 class RepositoryDataType(Enum):
@@ -35,8 +33,7 @@ class RepositoryDataType(Enum):
 
 
 class RepositoryScopedBatchLoader:
-    """
-    A batch loader that fetches an assortment of data for a given repository.  This loader is
+    """A batch loader that fetches an assortment of data for a given repository.  This loader is
     expected to be instantiated once per repository, and then passed to various child graphene
     objects to batch calls to the DB.
 
@@ -272,8 +269,7 @@ class RepositoryScopedBatchLoader:
 
 
 class BatchRunLoader:
-    """
-    A batch loader that fetches a set of runs by run_id. This loader is expected to be instantiated
+    """A batch loader that fetches a set of runs by run_id. This loader is expected to be instantiated
     once with a set of run_ids. For example, for a particular asset, we can fetch a list of asset
     materializations, all of which may have been materialized from a different run.
     """
@@ -299,8 +295,7 @@ class BatchRunLoader:
 
 
 class BatchMaterializationLoader:
-    """
-    A batch loader that fetches materializations for asset keys.  This loader is expected to be
+    """A batch loader that fetches materializations for asset keys.  This loader is expected to be
     instantiated with a set of asset keys.
     """
 
@@ -331,23 +326,8 @@ class BatchMaterializationLoader:
         }
 
 
-class CachingDynamicPartitionsLoader(DynamicPartitionsStore):
-    """
-    A batch loader that caches the partition keys for a given dynamic partitions definition,
-    to avoid repeated calls to the database for the same partitions definition.
-    """
-
-    def __init__(self, instance: DagsterInstance):
-        self._instance = instance
-
-    @cached_method
-    def get_dynamic_partitions(self, partitions_def_name: str) -> Sequence[str]:
-        return self._instance.get_dynamic_partitions(partitions_def_name)
-
-
 class CrossRepoAssetDependedByLoader:
-    """
-    A batch loader that computes cross-repository asset dependencies. Locates source assets
+    """A batch loader that computes cross-repository asset dependencies. Locates source assets
     within all workspace repositories, and determines if they are derived (defined) assets in
     other repositories.
 
@@ -373,8 +353,7 @@ class CrossRepoAssetDependedByLoader:
         Dict[AssetKey, ExternalAssetNode],
         Dict[Tuple[str, str], Dict[AssetKey, List[ExternalAssetDependedBy]]],
     ]:
-        """
-        This method constructs a sink asset as an ExternalAssetNode for every asset immediately
+        """This method constructs a sink asset as an ExternalAssetNode for every asset immediately
         downstream of a source asset that is defined in another repository as a derived asset.
 
         In Dagit, sink assets will display as ForeignAssets, which are external from the repository.
@@ -392,7 +371,7 @@ class CrossRepoAssetDependedByLoader:
         external_asset_node_by_asset_key: Dict[
             AssetKey, ExternalAssetNode
         ] = {}  # only contains derived assets
-        for location in self._context.repository_locations:
+        for location in self._context.code_locations:
             repositories = location.get_repositories()
             for repo_name, external_repo in repositories.items():
                 asset_nodes = external_repo.get_external_asset_nodes()
@@ -449,7 +428,7 @@ class CrossRepoAssetDependedByLoader:
 
     def get_cross_repo_dependent_assets(
         self, repository_location_name: str, repository_name: str, asset_key: AssetKey
-    ) -> List[ExternalAssetDependedBy]:
+    ) -> Sequence[ExternalAssetDependedBy]:
         _, external_asset_deps = self._build_cross_repo_deps()
         return external_asset_deps.get((repository_location_name, repository_name), {}).get(
             asset_key, []
