@@ -43,7 +43,7 @@ T_Callable = TypeVar("T_Callable", bound=Callable)
 
 def assert_permission_for_location(
     graphene_info: "ResolveInfo", permission: str, location_name: str
-):
+) -> None:
     from dagster_graphql.schema.errors import GrapheneUnauthorizedError
 
     context = cast(BaseWorkspaceRequestContext, graphene_info.context)
@@ -53,9 +53,7 @@ def assert_permission_for_location(
 
 def require_permission_check(permission: str) -> Callable[[GrapheneResolverFn], GrapheneResolverFn]:
     def decorator(fn: GrapheneResolverFn) -> GrapheneResolverFn:
-        def _fn(
-            self, graphene_info, *args: P.args, **kwargs: P.kwargs
-        ):  # pylint: disable=unused-argument
+        def _fn(self, graphene_info, *args: P.args, **kwargs: P.kwargs):
             result = fn(self, graphene_info, *args, **kwargs)
 
             if not graphene_info.context.was_permission_checked(permission):
@@ -70,9 +68,7 @@ def require_permission_check(permission: str) -> Callable[[GrapheneResolverFn],
 
 def check_permission(permission: str) -> Callable[[GrapheneResolverFn], GrapheneResolverFn]:
     def decorator(fn: GrapheneResolverFn) -> GrapheneResolverFn:
-        def _fn(
-            self, graphene_info, *args: P.args, **kwargs: P.kwargs
-        ):  # pylint: disable=unused-argument
+        def _fn(self, graphene_info, *args: P.args, **kwargs: P.kwargs):
             assert_permission(graphene_info, permission)
 
             return fn(self, graphene_info, *args, **kwargs)
@@ -125,7 +121,7 @@ class ErrorCapture:
 def capture_error(
     fn: Callable[P, T]
 ) -> Callable[P, Union[T, "GrapheneError", "GraphenePythonError"]]:
-    def _fn(*args: P.args, **kwargs: P.kwargs):
+    def _fn(*args: P.args, **kwargs: P.kwargs) -> T:
         try:
             return fn(*args, **kwargs)
         except UserFacingGraphQLError as de_exception:
@@ -246,3 +242,6 @@ class ExecutionMetadata(
             "rootRunId": self.root_run_id,
             "parentRunId": self.parent_run_id,
         }
+
+
+BackfillParams: TypeAlias = Mapping[str, Any]
