@@ -25,6 +25,7 @@ from dagster_graphql.implementation.fetch_partition_sets import (
 )
 from dagster_graphql.implementation.fetch_runs import get_runs
 
+from .asset_key import GrapheneAssetKey
 from .backfill import GraphenePartitionBackfill
 from .errors import (
     GrapheneDuplicateDynamicPartitionError,
@@ -121,6 +122,17 @@ class GraphenePartitionStatusesOrError(graphene.Union):
         name = "PartitionStatusesOrError"
 
 
+class GrapheneAssetPartitionsStatusCounts(graphene.ObjectType):
+    class Meta:
+        name = "AssetPartitionsStatusCounts"
+
+    assetKey = graphene.NonNull(GrapheneAssetKey)
+    numPartitionsTargeted = graphene.NonNull(graphene.Int)
+    numPartitionsRequested = graphene.NonNull(graphene.Int)
+    numPartitionsCompleted = graphene.NonNull(graphene.Int)
+    numPartitionsFailed = graphene.NonNull(graphene.Int)
+
+
 class GraphenePartitionTagsOrError(graphene.Union):
     class Meta:
         types = (GraphenePartitionTags, GraphenePythonError)
@@ -180,7 +192,7 @@ class GraphenePartition(graphene.ObjectType):
     def resolve_runs(
         self,
         graphene_info: ResolveInfo,
-        filter: Optional[GrapheneRunsFilter] = None,
+        filter: Optional[GrapheneRunsFilter] = None,  # noqa: A002
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
     ):
@@ -362,6 +374,7 @@ class GrapheneDimensionDefinitionType(graphene.ObjectType):
     description = graphene.NonNull(graphene.String)
     type = graphene.NonNull(GraphenePartitionDefinitionType)
     isPrimaryDimension = graphene.NonNull(graphene.Boolean)
+    dynamicPartitionsDefinitionName = graphene.Field(graphene.String)
 
     class Meta:
         name = "DimensionDefinitionType"
@@ -418,6 +431,11 @@ class GraphenePartitionDefinition(graphene.ObjectType):
                     == cast(
                         MultiPartitionsDefinition, partition_def_data.get_partitions_definition()
                     ).primary_dimension.name,
+                    dynamicPartitionsDefinitionName=dim.external_partitions_def_data.name
+                    if isinstance(
+                        dim.external_partitions_def_data, ExternalDynamicPartitionsDefinitionData
+                    )
+                    else None,
                 )
                 for dim in partition_def_data.external_partition_dimension_definitions
             ]
@@ -430,6 +448,9 @@ class GraphenePartitionDefinition(graphene.ObjectType):
                         partition_def_data
                     ),
                     isPrimaryDimension=True,
+                    dynamicPartitionsDefinitionName=partition_def_data.name
+                    if isinstance(partition_def_data, ExternalDynamicPartitionsDefinitionData)
+                    else None,
                 )
             ],
             timeWindowMetadata=_get_time_partitions_metadata(partition_def_data)
