@@ -1,10 +1,8 @@
-# pylint: disable=missing-graphene-docstring
 import graphene
 
-from ..errors import GraphenePipelineNotFoundError, GraphenePythonError
+from ..errors import GrapheneInvalidSubsetError, GraphenePipelineNotFoundError, GraphenePythonError
 from ..execution import GrapheneExecutionPlan
 from ..pipelines.config import GrapheneRunConfigValidationInvalid
-from ..pipelines.pipeline_errors import GrapheneInvalidSubsetError
 
 
 class GrapheneExecutionPlanOrError(graphene.Union):
