@@ -4,6 +4,7 @@ import dagster._check as check
 import graphene
 from dagster._core.definitions.events import AssetKey
 from dagster._core.definitions.external_asset_graph import ExternalAssetGraph
+from dagster._core.definitions.partition import CachingDynamicPartitionsLoader
 from dagster._core.definitions.selector import (
     InstigatorSelector,
     RepositorySelector,
@@ -44,7 +45,10 @@ from ...implementation.fetch_pipelines import (
     get_pipeline_snapshot_or_error_from_pipeline_selector,
     get_pipeline_snapshot_or_error_from_snapshot_id,
 )
-from ...implementation.fetch_resources import get_resource_or_error, get_resources_or_error
+from ...implementation.fetch_resources import (
+    get_resource_or_error,
+    get_top_level_resources_or_error,
+)
 from ...implementation.fetch_runs import (
     get_execution_plan,
     get_logs_for_run,
@@ -64,7 +68,6 @@ from ...implementation.fetch_sensors import get_sensor_or_error, get_sensors_or_
 from ...implementation.fetch_solids import get_graph_or_error
 from ...implementation.loader import (
     BatchMaterializationLoader,
-    CachingDynamicPartitionsLoader,
     CrossRepoAssetDependedByLoader,
     StaleStatusLoader,
 )
@@ -492,18 +495,18 @@ class GrapheneDagitQuery(graphene.ObjectType):
             not (snapshotId and activePipelineSelector),
             "Must only pass one of snapshotId or activePipelineSelector",
         )
-        check.invariant(
-            snapshotId or activePipelineSelector,
-            "Must set one of snapshotId or activePipelineSelector",
-        )
 
         if activePipelineSelector:
             pipeline_selector = pipeline_selector_from_graphql(activePipelineSelector)
             return get_pipeline_snapshot_or_error_from_pipeline_selector(
                 graphene_info, pipeline_selector
             )
-        else:
+        elif snapshotId:
             return get_pipeline_snapshot_or_error_from_snapshot_id(graphene_info, snapshotId)
+        else:
+            check.failed(
+                "Must set one of snapshotId or activePipelineSelector",
+            )
 
     def resolve_graphOrError(
         self, graphene_info: ResolveInfo, selector: Optional[GrapheneGraphSelector] = None
@@ -539,7 +542,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
         )
 
     def resolve_allTopLevelResourceDetailsOrError(self, graphene_info: ResolveInfo, **kwargs):
-        return get_resources_or_error(
+        return get_top_level_resources_or_error(
             graphene_info,
             RepositorySelector.from_graphql_input(kwargs.get("repositorySelector")),
         )
@@ -583,7 +586,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
     def resolve_pipelineRunsOrError(
         self,
         _graphene_info: ResolveInfo,
-        filter: Optional[GrapheneRunsFilter] = None,
+        filter: Optional[GrapheneRunsFilter] = None,  # noqa: A002
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
     ):
@@ -601,7 +604,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
     def resolve_runsOrError(
         self,
         _graphene_info: ResolveInfo,
-        filter: Optional[GrapheneRunsFilter] = None,
+        filter: Optional[GrapheneRunsFilter] = None,  # noqa: A002
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
     ):
@@ -619,7 +622,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
     def resolve_runGroupsOrError(
         self,
         graphene_info: ResolveInfo,
-        filter: Optional[GrapheneRunsFilter] = None,
+        filter: Optional[GrapheneRunsFilter] = None,  # noqa: A002
         cursor: Optional[str] = None,
         limit: Optional[int] = None,
     ):
@@ -728,7 +731,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
         if group is not None:
             group_name = group.groupName
             repo_sel = RepositorySelector.from_graphql_input(group)
-            repo_loc = graphene_info.context.get_repository_location(repo_sel.location_name)
+            repo_loc = graphene_info.context.get_code_location(repo_sel.location_name)
             repo = repo_loc.get_repository(repo_sel.repository_name)
             external_asset_nodes = repo.get_external_asset_nodes()
             results = (
@@ -748,7 +751,7 @@ class GrapheneDagitQuery(graphene.ObjectType):
         elif pipeline is not None:
             pipeline_name = pipeline.pipelineName
             repo_sel = RepositorySelector.from_graphql_input(pipeline)
-            repo_loc = graphene_info.context.get_repository_location(repo_sel.location_name)
+            repo_loc = graphene_info.context.get_code_location(repo_sel.location_name)
             repo = repo_loc.get_repository(repo_sel.repository_name)
             external_asset_nodes = repo.get_external_asset_nodes(pipeline_name)
             results = (
