@@ -15,6 +15,7 @@ from .errors import (
     GraphenePythonError,
     GrapheneRunGroupNotFoundError,
 )
+from .tags import GraphenePipelineTagAndValues
 from .util import ResolveInfo, non_null_list
 
 
@@ -137,6 +138,32 @@ class GrapheneRunGroupsOrError(graphene.ObjectType):
         name = "RunGroupsOrError"
 
 
+class GrapheneRunTagKeys(graphene.ObjectType):
+    keys = non_null_list(graphene.String)
+
+    class Meta:
+        name = "RunTagKeys"
+
+
+class GrapheneRunTagKeysOrError(graphene.Union):
+    class Meta:
+        types = (GraphenePythonError, GrapheneRunTagKeys)
+        name = "RunTagKeysOrError"
+
+
+class GrapheneRunTags(graphene.ObjectType):
+    tags = non_null_list(GraphenePipelineTagAndValues)
+
+    class Meta:
+        name = "RunTags"
+
+
+class GrapheneRunTagsOrError(graphene.Union):
+    class Meta:
+        types = (GraphenePythonError, GrapheneRunTags)
+        name = "RunTagsOrError"
+
+
 class GrapheneRunConfigData(GenericScalar, graphene.Scalar):
     class Meta:
         description = """This type is used when passing in a configuration object
