@@ -1,7 +1,9 @@
 import graphene
-from dagster._core.host_representation import ScheduleSelector
+from dagster._core.definitions.selector import ScheduleSelector
 from dagster._core.workspace.permissions import Permissions
 
+from dagster_graphql.schema.util import ResolveInfo
+
 from ...implementation.fetch_schedules import start_schedule, stop_schedule
 from ...implementation.utils import (
     assert_permission_for_location,
@@ -72,7 +74,7 @@ class GrapheneStartScheduleMutation(graphene.Mutation):
 
     @capture_error
     @require_permission_check(Permissions.START_SCHEDULE)
-    def mutate(self, graphene_info, schedule_selector):
+    def mutate(self, graphene_info: ResolveInfo, schedule_selector):
         selector = ScheduleSelector.from_graphql_input(schedule_selector)
         assert_permission_for_location(
             graphene_info, Permissions.START_SCHEDULE, selector.location_name
@@ -94,7 +96,7 @@ class GrapheneStopRunningScheduleMutation(graphene.Mutation):
 
     @capture_error
     @require_permission_check(Permissions.STOP_RUNNING_SCHEDULE)
-    def mutate(self, graphene_info, schedule_origin_id, schedule_selector_id):
+    def mutate(self, graphene_info: ResolveInfo, schedule_origin_id, schedule_selector_id):
         return stop_schedule(graphene_info, schedule_origin_id, schedule_selector_id)
 
 
