@@ -1,13 +1,14 @@
 from functools import lru_cache
-from typing import List, Mapping, Optional, Sequence, Union
+from typing import TYPE_CHECKING, List, Mapping, Optional, Sequence, Union
 
 import dagster._check as check
 import graphene
 from dagster._core.definitions import NodeHandle
 from dagster._core.host_representation import RepresentedPipeline
+from dagster._core.host_representation.external import ExternalPipeline
 from dagster._core.host_representation.historical import HistoricalPipeline
-from dagster._core.snap import CompositeSolidDefSnap, DependencyStructureIndex, SolidDefSnap
-from dagster._core.snap.solid import InputMappingSnap, OutputMappingSnap
+from dagster._core.snap import DependencyStructureIndex, GraphDefSnap, OpDefSnap
+from dagster._core.snap.node import InputMappingSnap, OutputMappingSnap
 from dagster._core.storage.pipeline_run import RunsFilter
 
 from dagster_graphql.implementation.events import iterate_metadata_entries
@@ -15,11 +16,14 @@ from dagster_graphql.schema.logs.events import GrapheneRunStepStats
 from dagster_graphql.schema.metadata import GrapheneMetadataEntry
 
 from .config_types import GrapheneConfigTypeField
-from .dagster_types import GrapheneDagsterType, to_dagster_type
+from .dagster_types import GrapheneDagsterType, GrapheneDagsterTypeUnion, to_dagster_type
 from .errors import GrapheneError
 from .metadata import GrapheneMetadataItemDefinition
 from .util import ResolveInfo, non_null_list
 
+if TYPE_CHECKING:
+    from .asset_graph import GrapheneAssetNode
+
 
 class _ArgNotPresentSentinel:
     pass
@@ -50,7 +54,7 @@ class GrapheneInputDefinition(graphene.ObjectType):
             description=self._input_def_snap.description,
         )
 
-    def resolve_type(self, _graphene_info):
+    def resolve_type(self, _graphene_info: ResolveInfo) -> GrapheneDagsterTypeUnion:
         return to_dagster_type(
             self._represented_pipeline.pipeline_snapshot, self._input_def_snap.dagster_type_key
         )
@@ -58,12 +62,10 @@ class GrapheneInputDefinition(graphene.ObjectType):
     def resolve_solid_definition(
         self, _graphene_info: ResolveInfo
     ) -> Union["GrapheneSolidDefinition", "GrapheneCompositeSolidDefinition"]:
-        return build_solid_definition(
-            self._represented_pipeline, self._solid_def_snap.name  # pylint: disable=no-member
-        )
+        return build_solid_definition(self._represented_pipeline, self._solid_def_snap.name)
 
     def resolve_metadata_entries(self, _graphene_info):
-        return list(iterate_metadata_entries(self._input_def_snap.metadata_entries))
+        return list(iterate_metadata_entries(self._input_def_snap.metadata))
 
 
 class GrapheneOutputDefinition(graphene.ObjectType):
@@ -99,17 +101,19 @@ class GrapheneOutputDefinition(graphene.ObjectType):
             is_dynamic=is_dynamic,
         )
 
-    def resolve_type(self, _graphene_info):
+    def resolve_type(self, _graphene_info) -> GrapheneDagsterTypeUnion:
         return to_dagster_type(
             self._represented_pipeline.pipeline_snapshot,
             self._output_def_snap.dagster_type_key,
         )
 
-    def resolve_solid_definition(self, _graphene_info):
+    def resolve_solid_definition(
+        self, _graphene_info
+    ) -> Union["GrapheneSolidDefinition", "GrapheneCompositeSolidDefinition"]:
         return build_solid_definition(self._represented_pipeline, self._solid_def_snap.name)
 
     def resolve_metadata_entries(self, _graphene_info):
-        return list(iterate_metadata_entries(self._output_def_snap.metadata_entries))
+        return list(iterate_metadata_entries(self._output_def_snap.metadata))
 
 
 class GrapheneInput(graphene.ObjectType):
@@ -138,7 +142,7 @@ class GrapheneInput(graphene.ObjectType):
         self._input_name = check.str_param(input_name, "input_name")
         self._solid_invocation_snap = current_dep_structure.get_invocation(solid_name)
         self._solid_def_snap = represented_pipeline.get_node_def_snap(
-            self._solid_invocation_snap.solid_def_name
+            self._solid_invocation_snap.node_def_name
         )
         self._input_def_snap = self._solid_def_snap.get_input_snap(input_name)
 
@@ -161,7 +165,7 @@ class GrapheneInput(graphene.ObjectType):
             GrapheneOutput(
                 self._represented_pipeline,
                 self._current_dep_structure,
-                output_handle_snap.solid_name,
+                output_handle_snap.node_name,
                 output_handle_snap.output_name,
             )
             for output_handle_snap in self._current_dep_structure.get_upstream_outputs(
@@ -192,7 +196,7 @@ class GrapheneOutput(graphene.ObjectType):
         self._output_name = check.str_param(output_name, "output_name")
         self._solid_invocation_snap = current_dep_structure.get_invocation(solid_name)
         self._solid_def_snap = represented_pipeline.get_node_def_snap(
-            self._solid_invocation_snap.solid_def_name
+            self._solid_invocation_snap.node_def_name
         )
         self._output_def_snap = self._solid_def_snap.get_output_snap(output_name)
         super().__init__()
@@ -215,7 +219,7 @@ class GrapheneOutput(graphene.ObjectType):
             GrapheneInput(
                 self._represented_pipeline,
                 self._current_dep_structure,
-                input_handle_snap.solid_name,
+                input_handle_snap.node_name,
                 input_handle_snap.input_name,
             )
             for input_handle_snap in self._current_dep_structure.get_downstream_inputs(
@@ -254,7 +258,7 @@ class GrapheneInputMapping(graphene.ObjectType):
         return GrapheneInput(
             self._represented_pipeline,
             self._current_dep_index,
-            self._input_mapping_snap.mapped_solid_name,
+            self._input_mapping_snap.mapped_node_name,
             self._input_mapping_snap.mapped_input_name,
         )
 
@@ -296,7 +300,7 @@ class GrapheneOutputMapping(graphene.ObjectType):
         return GrapheneOutput(
             self._represented_pipeline,
             self._current_dep_index,
-            self._output_mapping_snap.mapped_solid_name,
+            self._output_mapping_snap.mapped_node_name,
             self._output_mapping_snap.mapped_output_name,
         )
 
@@ -325,7 +329,7 @@ def build_solids(represented_pipeline, current_dep_index):
     return sorted(
         [
             GrapheneSolid(represented_pipeline, solid_name, current_dep_index)
-            for solid_name in current_dep_index.solid_invocation_names
+            for solid_name in current_dep_index.node_invocation_names
         ],
         key=lambda solid: solid.name,
     )
@@ -339,15 +343,15 @@ def _build_solid_handles(
     check.inst_param(represented_pipeline, "represented_pipeline", RepresentedPipeline)
     check.opt_inst_param(parent, "parent", GrapheneSolidHandle)
     all_handle: List[GrapheneSolidHandle] = []
-    for solid_invocation in current_dep_index.solid_invocations:
-        solid_name, solid_def_name = solid_invocation.solid_name, solid_invocation.solid_def_name
+    for solid_invocation in current_dep_index.node_invocations:
+        solid_name, solid_def_name = solid_invocation.node_name, solid_invocation.node_def_name
         handle = GrapheneSolidHandle(
             solid=GrapheneSolid(represented_pipeline, solid_name, current_dep_index),
             handle=NodeHandle(solid_name, parent.handleID if parent else None),
             parent=parent if parent else None,
         )
         solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
-        if isinstance(solid_def_snap, CompositeSolidDefSnap):
+        if isinstance(solid_def_snap, GraphDefSnap):
             all_handle += _build_solid_handles(
                 represented_pipeline,
                 represented_pipeline.get_dep_structure_index(solid_def_name),
@@ -385,7 +389,7 @@ class GrapheneISolidDefinition(graphene.Interface):
 
 
 class ISolidDefinitionMixin:
-    def __init__(self, represented_pipeline, solid_def_name):
+    def __init__(self, represented_pipeline: RepresentedPipeline, solid_def_name: str):
         self._represented_pipeline = check.inst_param(
             represented_pipeline, "represented_pipeline", RepresentedPipeline
         )
@@ -399,10 +403,10 @@ class ISolidDefinitionMixin:
         ]
 
     @property
-    def solid_def_name(self):
+    def solid_def_name(self) -> str:
         return self._solid_def_snap.name
 
-    def resolve_input_definitions(self, _graphene_info):
+    def resolve_input_definitions(self, _graphene_info) -> Sequence[GrapheneInputDefinition]:
         return [
             GrapheneInputDefinition(
                 self._represented_pipeline, self.solid_def_name, input_def_snap.name
@@ -421,7 +425,7 @@ class ISolidDefinitionMixin:
             for output_def_snap in self._solid_def_snap.output_def_snaps
         ]
 
-    def resolve_asset_nodes(self, graphene_info):
+    def resolve_asset_nodes(self, graphene_info: ResolveInfo) -> Sequence["GrapheneAssetNode"]:
         # NOTE: This is a temporary hack. We really should prob be resolving solids against the repo
         # rather than pipeline, that way we would not have to refetch the repo here here in order to
         # access the asset nodes.
@@ -431,9 +435,10 @@ class ISolidDefinitionMixin:
         if isinstance(self._represented_pipeline, HistoricalPipeline):
             return []
         else:
+            assert isinstance(self._represented_pipeline, ExternalPipeline)
             repo_handle = self._represented_pipeline.repository_handle
-            origin = repo_handle.repository_location_origin
-            location = graphene_info.context.get_repository_location(origin.location_name)
+            origin = repo_handle.code_location_origin
+            location = graphene_info.context.get_code_location(origin.location_name)
             ext_repo = location.get_repository(repo_handle.repository_name)
             nodes = [
                 node
@@ -454,13 +459,15 @@ class GrapheneSolidDefinition(graphene.ObjectType, ISolidDefinitionMixin):
     def __init__(self, represented_pipeline: RepresentedPipeline, solid_def_name: str):
         check.inst_param(represented_pipeline, "represented_pipeline", RepresentedPipeline)
         _solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
-        if not isinstance(_solid_def_snap, SolidDefSnap):
+        if not isinstance(_solid_def_snap, OpDefSnap):
             check.failed("Expected SolidDefSnap")
         self._solid_def_snap = _solid_def_snap
         super().__init__(name=solid_def_name, description=self._solid_def_snap.description)
         ISolidDefinitionMixin.__init__(self, represented_pipeline, solid_def_name)
 
-    def resolve_config_field(self, _graphene_info):
+    def resolve_config_field(
+        self, _graphene_info: ResolveInfo
+    ) -> Optional[GrapheneConfigTypeField]:
         return (
             GrapheneConfigTypeField(
                 config_schema_snapshot=self._represented_pipeline.config_schema_snapshot,
@@ -470,7 +477,9 @@ class GrapheneSolidDefinition(graphene.ObjectType, ISolidDefinitionMixin):
             else None
         )
 
-    def resolve_required_resources(self, _graphene_info):
+    def resolve_required_resources(
+        self, _graphene_info: ResolveInfo
+    ) -> Sequence[GrapheneResourceRequirement]:
         return [
             GrapheneResourceRequirement(key) for key in self._solid_def_snap.required_resource_keys
         ]
@@ -522,7 +531,7 @@ class GrapheneSolid(graphene.ObjectType):
         )
         self._solid_invocation_snap = current_dep_structure.get_invocation(solid_name)
         self._solid_def_snap = represented_pipeline.get_node_def_snap(
-            self._solid_invocation_snap.solid_def_name
+            self._solid_invocation_snap.node_def_name
         )
         super().__init__(name=solid_name)
 
@@ -538,7 +547,7 @@ class GrapheneSolid(graphene.ObjectType):
         return self._solid_invocation_snap.is_dynamic_mapped
 
     def get_is_composite(self) -> bool:
-        return isinstance(self._solid_def_snap, CompositeSolidDefSnap)
+        return isinstance(self._solid_def_snap, GraphDefSnap)
 
     def get_pipeline_name(self) -> str:
         return self._represented_pipeline.name
@@ -553,7 +562,7 @@ class GrapheneSolid(graphene.ObjectType):
             GrapheneInput(
                 self._represented_pipeline,
                 self._current_dep_structure,
-                self._solid_invocation_snap.solid_name,
+                self._solid_invocation_snap.node_name,
                 input_def_snap.name,
             )
             for input_def_snap in self._solid_def_snap.input_def_snaps
@@ -564,7 +573,7 @@ class GrapheneSolid(graphene.ObjectType):
             GrapheneOutput(
                 self._represented_pipeline,
                 self._current_dep_structure,
-                self._solid_invocation_snap.solid_name,
+                self._solid_invocation_snap.node_name,
                 output_def_snap.name,
             )
             for output_def_snap in self._solid_def_snap.output_def_snaps
@@ -596,7 +605,7 @@ class GrapheneSolidHandle(graphene.ObjectType):
         )
         self._solid = solid
 
-    def resolve_stepStats(self, _graphene_info, limit):
+    def resolve_stepStats(self, _graphene_info: ResolveInfo, limit: Optional[int]):
         if self._solid.get_is_dynamic_mapped():
             return GrapheneSolidStepStatsUnavailableError(
                 message="Step stats are not available for dynamically-mapped ops"
@@ -656,7 +665,7 @@ class GrapheneCompositeSolidDefinition(graphene.ObjectType, ISolidDefinitionMixi
         interfaces = (GrapheneISolidDefinition, GrapheneSolidContainer)
         name = "CompositeSolidDefinition"
 
-    def __init__(self, represented_pipeline, solid_def_name):
+    def __init__(self, represented_pipeline: RepresentedPipeline, solid_def_name: str):
         self._represented_pipeline = check.inst_param(
             represented_pipeline, "represented_pipeline", RepresentedPipeline
         )
@@ -665,13 +674,16 @@ class GrapheneCompositeSolidDefinition(graphene.ObjectType, ISolidDefinitionMixi
         super().__init__(name=solid_def_name, description=self._solid_def_snap.description)
         ISolidDefinitionMixin.__init__(self, represented_pipeline, solid_def_name)
 
-    def resolve_id(self, _graphene_info):
+    def resolve_id(self, _graphene_info: ResolveInfo) -> str:
         return f"{self._represented_pipeline.identifying_pipeline_snapshot_id}:{self._solid_def_snap.name}"
 
-    def resolve_solids(self, _graphene_info):
+    def resolve_solids(self, _graphene_info: ResolveInfo) -> Sequence[GrapheneSolid]:
         return build_solids(self._represented_pipeline, self._comp_solid_dep_index)
 
-    def resolve_output_mappings(self, _graphene_info):
+    def resolve_output_mappings(
+        self, _graphene_info: ResolveInfo
+    ) -> Sequence[GrapheneOutputMapping]:
+        assert isinstance(self._solid_def_snap, GraphDefSnap)
         return [
             GrapheneOutputMapping(
                 self._represented_pipeline,
@@ -682,7 +694,8 @@ class GrapheneCompositeSolidDefinition(graphene.ObjectType, ISolidDefinitionMixi
             for output_mapping_snap in self._solid_def_snap.output_mapping_snaps
         ]
 
-    def resolve_input_mappings(self, _graphene_info):
+    def resolve_input_mappings(self, _graphene_info: ResolveInfo) -> Sequence[GrapheneInputMapping]:
+        assert isinstance(self._solid_def_snap, GraphDefSnap)
         return [
             GrapheneInputMapping(
                 self._represented_pipeline,
@@ -693,7 +706,9 @@ class GrapheneCompositeSolidDefinition(graphene.ObjectType, ISolidDefinitionMixi
             for input_mapping_snap in self._solid_def_snap.input_mapping_snaps
         ]
 
-    def resolve_solid_handle(self, _graphene_info, handleID):
+    def resolve_solid_handle(
+        self, _graphene_info: ResolveInfo, handleID: str
+    ) -> Optional[GrapheneSolidHandle]:
         return build_solid_handles(self._represented_pipeline).get(handleID)
 
     def resolve_solid_handles(
@@ -726,13 +741,13 @@ def build_solid_definition(
 
     solid_def_snap = represented_pipeline.get_node_def_snap(solid_def_name)
 
-    if isinstance(solid_def_snap, SolidDefSnap):
+    if isinstance(solid_def_snap, OpDefSnap):
         return GrapheneSolidDefinition(represented_pipeline, solid_def_snap.name)
 
-    if isinstance(solid_def_snap, CompositeSolidDefSnap):
+    if isinstance(solid_def_snap, GraphDefSnap):
         return GrapheneCompositeSolidDefinition(represented_pipeline, solid_def_snap.name)
 
-    check.failed("Unknown solid definition type {type}".format(type=type(solid_def_snap)))
+    check.failed(f"Unknown solid definition type {type(solid_def_snap)}")
 
 
 types = [
